@@ -117,6 +117,17 @@ class Background:
         f.write(tmppp)
         f.close()
         print('Save {0}'.format(string))
+        # save only bkg
+        string = './{1}/{0}'.format(self.data['gfile'].split('/')[-1].split('_')[0]+'_bkg.fits',savefolder)
+        os.system('cp {0} {1}'.format(self.data['gfile'],string))
+        tmpp = fits.open(string)
+        tmppdata = tmpp[self.data['extnum']].data
+        bb0x,bb1x = self.bbox['bbox']['BBX']
+        bb0y,bb1y = self.bbox['bbox']['BBY']
+        yfit = self.bkg.model['YFIT']
+        tmppdata[bb0y:bb1y,bb0x:bb1x] = yfit.copy()
+        tmpp.writeto(string,overwrite=True)
+        print('Save {0}'.format(string))
     ##########
     ##########
     ##########
